#!/usr/bin/env python3

import argparse
import subprocess
from pathlib import Path

from loguru import logger


def main():
    parser = argparse.ArgumentParser('图像转换工具')
    parser.add_argument('file', type=Path, help='待转换文件')
    parser.add_argument('ext', type=str, help='目标文件扩展名, 如: .jpg')
    parser.add_argument('--remove', action='store_true', help='转化成功则删除源文件')
    parser.add_argument('-v', '--verbose', action='store_true', help='显示详细信息')
    opt = parser.parse_args()

    src_file: Path = opt.file  # type: ignore
    if src_file.suffix == opt.ext:
        return

    src_size = src_file.stat().st_size
    if src_size < 1000:
        logger.error(f'源文件尺寸无效: {src_size}')
        return

    dst_file: Path = src_file.with_suffix(opt.ext)  # type: ignore
    if not dst_file.exists():
        r = subprocess.call(['convert', src_file, dst_file])
        if r != 0:
            logger.error(f'转换失败, r={r}, file={dst_file}')
            return
    if not dst_file.exists():
        logger.error(f'目标路径不存在: {dst_file}')
        return

    r = subprocess.call(['identify', dst_file])
    if r != 0:
        logger.error(f'验证失败: {r}')
        return

    dst_size = dst_file.stat().st_size
    if dst_size < 1000:
        logger.error(f'目标文件尺寸无效: {dst_size}')
        return

    radio = int(dst_size / src_size * 100)
    logger.debug(f'{src_file}({radio}%)')

    if opt.remove:
        src_file.unlink()
        logger.info(f'{src_file} 删除!')


if __name__ == '__main__':
    main()



from pydantic import BaseModel


class Endpoint(BaseModel):
    host: str
    port: int

    def __str__(self) -> str:
        return '%s:%d' % (self.host, self.port)


class ApiCfg(BaseModel):
    name: str
    root: str
    endpoint: Endpoint

    def url(self, scheme: str) -> str:
        """获取URL"""
        return '%s://%s/%s' % (scheme, self.endpoint, self.root)


def test_cfg() -> None:
    _cfg = ApiCfg(name='配置', root='/howell/ias', endpoint=Endpoint(host='localhost', port=5000))
    assert _cfg.name == '配置'



import argparse
import shutil
from pathlib import Path

from jcx.sys.fs import files_in


def main() -> None:
    parser = argparse.ArgumentParser('从参考目录选择文件名, 从候选目录选出文件')
    parser.add_argument('ref_dir', type=Path, help='参考文件目录')
    parser.add_argument('candi_dir', type=Path, help='候选文件目录')
    parser.add_argument('dst_dir', type=Path, help='候选文件目录')
    parser.add_argument('-r', '--ref_ext', type=str, default='json', help='参考文件扩展名')
    parser.add_argument('-o', '--candi_ext', type=str, default='jpg', help='候选文件扩展名')
    parser.add_argument('-v', '--verbose', action='store_true', help='显示详细信息')
    opt = parser.parse_args()

    assert Path(opt.ref_dir).is_dir(), '参考文件目录不存在: ' + opt.ref_dir
    assert Path(opt.candi_dir).is_dir(), '候选文件目录不存在: ' + opt.candi_dir

    mates = files_in(opt.ref_dir, opt.ref_ext)
    names = [f.stem for f in mates]

    for i, name in enumerate(names):
        f = Path(opt.candi_dir, name + '.' + opt.candi_ext)
        assert Path(f).is_file(), f'文件不存在: {f}'
        shutil.copy(f, opt.dst_dir)


if __name__ == '__main__':
    main()



import argparse
import shutil
from pathlib import Path

from jcx.sys.fs import files_in, mtime_to_name, ctime_to_name


def main():
    parser = argparse.ArgumentParser('文件改名/复制工具')
    parser.add_argument('src_dir', type=Path, help='文件来源目录')
    parser.add_argument('dst_dir', type=Path, help='文件目标目录')
    parser.add_argument('-e', '--ext', type=str, default='jpg', help='文件扩展名')
    parser.add_argument('-m', '--method', type=str, required=True,
                        help='改名方法：ctime-改为创建时间, mtime-改为修改时间, now-改为当前时间')
    parser.add_argument('-v', '--verbose', action='store_true', help='显示详细信息')
    opt = parser.parse_args()

    methods = {'ctime': ctime_to_name, 'mtime': mtime_to_name}
    method = methods[opt.method]

    files = files_in(opt.src_dir, opt.ext)
    for src in files:
        name = method(src)
        dst = Path(opt.dst_dir) / name
        print(src.name, ' -> ', dst.name)
        dst.parent.mkdir(parents=True, exist_ok=True)
        shutil.copy(src, dst)


if __name__ == '__main__':
    main()



import argparse
import subprocess
from pathlib import Path

from jcx.sys.fs import du
from loguru import logger

cmd_map = {
    '.zip': ['unzip' '-O' 'GBK']
}


def main():
    parser = argparse.ArgumentParser('解压缩工具')
    parser.add_argument('file', type=Path, help='待解压文件')
    parser.add_argument('--remove', action='store_true', help='转化成功则删除源文件')
    parser.add_argument('-v', '--verbose', action='store_true', help='显示详细信息')
    opt = parser.parse_args()

    src_file = Path(opt.file)
    cmd = cmd_map.get(src_file.suffix)
    if cmd is None:
        return logger.error(f'未知文件格式: {src_file}')

    src_size = src_file.stat().st_size
    if src_size < 1000:
        return logger.error(f'源文件尺寸无效: {src_file}({src_size})')

    dst_file = src_file.with_suffix('')
    if not dst_file.exists():
        cmd.append(str(src_file))
        r = subprocess.call(cmd)
        if r != 0:
            return logger.error(f'解压失败, r={r}, file={dst_file}')

    if not dst_file.exists():
        return logger.error(f'目标路径不存在: {dst_file}')

    dst_size = du(dst_file)

    radio = int(dst_size / src_size * 100)
    logger.debug(f'{src_file}({radio}%)')

    if radio < 100:
        return logger.error(f'解压文件尺寸小于源文件: {src_file}')

    if opt.remove:
        src_file.unlink()
        logger.info('源文件删除!')


if __name__ == '__main__':
    main()



#!/opt/ias/env/bin/python

import argparse
from pathlib import Path

from jcx.sys.fs import files_in


def has_mate(file: Path, names: list) -> bool:
    """检查文件是否有伙伴文件"""
    for name in names:
        # print('math:', name, file.stem)
        if name.startswith(file.stem):
            return True
    return False


def main() -> None:
    parser = argparse.ArgumentParser('文件查找工具')
    parser.add_argument('src_dir', type=Path, help='文件来源目录')
    parser.add_argument('-e', '--ext', type=str, default='jpg', help='文件扩展名')
    parser.add_argument('-m', '--mate_ext', type=str, default='lbl', help='文件伙伴文件扩展名')
    parser.add_argument('-i', '--invert_match', action='store_true', help='选中不匹配的文件')
    parser.add_argument('-v', '--verbose', action='store_true', help='显示详细信息')
    opt = parser.parse_args()

    mates = files_in(opt.src_dir, opt.mate_ext)
    names = [f.stem for f in mates]

    candidates = files_in(opt.src_dir, opt.ext)

    for f in candidates:
        if has_mate(f, names) != opt.invert_match:
            print(f)


if __name__ == '__main__':
    main()



#!/usr/bin/env python3

import argparse
import glob
import os
import sys
from shutil import copyfile


def folder_files(folder, ext):
    if os.path.isdir(folder):
        s = os.path.join(folder, '**/*.' + ext)
        files = glob.glob(s, recursive=True)
        files.sort()
    else:
        print("数据源不存在:", folder)
        sys.exit(0)
    return files


def copy_file(src, dst):
    try:
        copyfile(src, dst)
        print(' ', dst)
    except IOError as e:
        print("无法复制文件：%s 错误信息：%s" % (src, e))


def main() -> None:
    parser = argparse.ArgumentParser('文件复制工具')
    parser.add_argument('src_dir', type=str, help='文件来源目录')
    parser.add_argument('dst_dir', type=str, help='文件目标目录')
    parser.add_argument('-e', '--ext', type=str, default='jpg', help='文件扩展名')
    parser.add_argument('-r', '--retain_num', type=int, default=5, help='保留的路径节数')
    parser.add_argument('-m', '--make_date_dir', action='store_true', help='创建日期目录')
    parser.add_argument('-v', '--verbose', action='store_true', help='显示详细信息')
    opt = parser.parse_args()

    files = folder_files(opt.src_dir, opt.ext)

    for src in files:
        parts = src.split('/')[-opt.retain_num:]
        name = '_'.join(parts)
        dst = os.path.join(opt.dst_dir, name)
        copy_file(src, dst)


if __name__ == '__main__':
    main()
